Unofficial Library to read values from an [Arvio Emaxx](http://arvio.com.au/systems-products/), a device that interfaces with Selectronic Inverters to read their state.

Just grabs the Battery State of Charge for now.

Note: I'm not affiliated with Arvio or Selectronic - I just had a need to get this data for inclusion in my Home Assistant set up.